Changelog
=========

.. You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst

.. towncrier release notes start

1.1.5 (2020-04-20)
------------------

Bug fixes:


- Minor packaging updates. (#1)


1.1.4 (2020-03-21)
------------------

Bug fixes:


- Minor packaging updates. [various] (#1)


1.1.3 (2018-11-21)
------------------

Bug fixes:


- Cleanup project level files (setup.py, .travis-ci.yml...) [maurits]
  [gforcada] (#2524)
- Initialized towncrier. [gforcada] (#2548)


1.1.3 (unreleased)
------------------


1.1.2 (2018-11-21)
------------------

Bug fixes:

- Update code to follow Plone styleguide.
  [gforcada]

1.1 (2016-11-01)
----------------

New features:

- Add compatibility with Python 3. [datakurre]


1.0.1 (2016-08-11)
------------------

Fixes:

- Use zope.interface decorator.
  [gforcada]


1.0 (2011-04-30)
----------------

- Use doctest from the stdlib instead of from zope.testing
  [davisagli]


1.0a1 (2009-04-17)
------------------

- Initial release.
